==> nodejs_interop-0.7.0.tar.gz: test/node/globals_test.dart <==
import 'dart:js_util';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:path/path.dart' as path;
import 'package:test/test.dart';

/// Tests the features of the Node.js globals.
void main() {
  final isWindows = process.platform == 'win32';

  group('dirname', () {
    test('should be the directory path of the current module', () {
      expect(dirname, equals(path.dirname(filename)));
    });
  });

  group('exports', () {
    test('should allow the creation or deletion of new properties', () {
      expect(getProperty(exports, 'fooBar'), isNull);
      setProperty(exports, 'fooBar', 'bazQux');
      expect(getProperty(exports, 'fooBar'), equals('bazQux'));
      Reflect.deleteProperty(exports, 'fooBar');
      expect(getProperty(exports, 'fooBar'), isNull);
    });
  });

  group('filename', () {
    test('should be the file path of the current module', () {
      expect(filename, endsWith(isWindows ? r'\globals_test.dart.node_test.dart.js' : '/globals_test.dart.node_test.dart.js'));
      expect(path.isAbsolute(filename), isTrue);
    });
  });

  group('global', () {
    test('should be the global namespace object', () {
      expect(hasProperty(global, 'Array'), isTrue);
      expect(hasProperty(global, 'Boolean'), isTrue);
      expect(hasProperty(global, 'Date'), isTrue);
      expect(hasProperty(global, 'Number'), isTrue);
      expect(hasProperty(global, 'Symbol'), isTrue);
    });

    test('should allow the creation or deletion of new properties', () {
      expect(getProperty(global, 'fooBar'), isNull);
      setProperty(global, 'fooBar', 'bazQux');
      expect(getProperty(global, 'fooBar'), equals('bazQux'));
      Reflect.deleteProperty(global, 'fooBar');
      expect(getProperty(global, 'fooBar'), isNull);
    });
  });
}

==> nodejs_interop-0.8.0.tar.gz: test/node/globals_test.dart <==
import 'package:nodejs_interop/js.dart';
import 'package:nodejs_interop/node.dart';
import 'package:path/path.dart' as path;
import 'package:test/test.dart';

/// Tests the features of the `nodejs_interop.node` globals.
void main() {
  group('dirname', () {
    test('should be the directory path of the current module', () {
      expect(dirname, equals(path.dirname(filename)));
    });
  });

  group('exports', () {
    test('should allow the creation or deletion of new properties', () {
      expect(getProperty(exports, 'fooBar'), isNull);
      setProperty(exports, 'fooBar', 'bazQux');
      expect(getProperty(exports, 'fooBar'), equals('bazQux'));
      deleteProperty(exports, 'fooBar');
      expect(getProperty(exports, 'fooBar'), isNull);
    });
  });

  group('filename', () {
    test('should be the file path of the current module', () {
      expect(filename, endsWith('globals_test.dart.node_test.dart.js'));
      expect(path.isAbsolute(filename), isTrue);
    });
  });

  group('global', () {
    test('should be the global namespace object', () {
      expect(hasProperty(global, 'Array'), isTrue);
      expect(hasProperty(global, 'Boolean'), isTrue);
      expect(hasProperty(global, 'Date'), isTrue);
      expect(hasProperty(global, 'Number'), isTrue);
      expect(hasProperty(global, 'Symbol'), isTrue);
    });

    test('should allow the creation or deletion of new properties', () {
      expect(getProperty(global, 'fooBar'), isNull);
      setProperty(global, 'fooBar', 'bazQux');
      expect(getProperty(global, 'fooBar'), equals('bazQux'));
      deleteProperty(global, 'fooBar');
      expect(getProperty(global, 'fooBar'), isNull);
    });
  });
}
